#pragma once

#include <exception>
#include <string>

namespace Combustion
{
	/*
		Thrown by MemoryManager when a problem is encountered
		Functions allow the user to request the amount of information
		they would like to display

		errorMessage: details the exact problem encountered
		linenumber:   the line of the instruction which triggered the exception
		filename:     the filename of the line which triggered the exception
	*/
	class MemoryException : public std::exception
	{
	public:
		MemoryException(const char* msg, int linenumber, char* filename)
			: errorMessage(msg), line(linenumber), file(filename)
		{}

		/* Returns the message describing the exception */
		virtual const char* what() { return errorMessage; }

		/* Returns the line number that triggered the exception */
		virtual int GetLine() {	return line; }

		/* Returns the file of the line number that triggered the exception */
		virtual char* GetFile() { return file; }

	private:
		const char* errorMessage;
		int line;
		char* file;
	};
}